@@ -1,5 +1,6 @@
 from .extension import hide_route, QuartSchema, SchemaValidationError
 from .validation import (
+    DataSource,
     RequestSchemaValidationError,
     ResponseSchemaValidationError,
     validate_querystring,
@@ -8,6 +9,7 @@ from .validation import (
 )
 
 __all__ = (
+    "DataSource",
     "hide_route",
     "QuartSchema",
     "RequestSchemaValidationError",
